@@ -38,12 +38,14 @@ void Status::ClearStatus()
   type=typeNone;
   essid.clear();
   bitrate=0;
+  channel=-1;
   quality=-1;
   signal=-1;
   noise=-1;
   accesspoint.clear();
   mac.clear();
   ip.clear();
+  powerSaving=powerSavingUnknown;
 }
 
 int Status::GetQualityFromSignalNoiseDbm(int signal, int noise)
@@ -70,3 +72,14 @@ bool Status::UpdateNetworks()
 {
   return false;
 }
+
+bool Status::CanChangePowerSaving() const
+{
+  return false;
+}
+
+bool Status::SetPowerSaving(bool /*savePower*/)
+{
+  return false;
+}
+
