@@ -42,12 +42,19 @@ public:
     typeMesh             //! Mesh network
   };
 
+  enum PowerSaving {
+    powerSavingOn,
+    powerSavingOff,
+    powerSavingUnknown
+  };
+
   class Network
   {
   public:
     std::wstring essid;
     Type         type;
     unsigned     bitrate;
+    int          channel;
     int          quality;
 
     Network()
@@ -60,6 +67,7 @@ public:
       type=typeNone;
       bitrate=0;
       quality=-1;
+      channel=-1;
     }
   };
 
@@ -69,12 +77,15 @@ public:
   Type               type;
   std::wstring       essid;
   unsigned           bitrate;
+  int                channel;
   int                quality; // [0..100%]
   int                signal;  // dBm
   int                noise;   // dBm
   std::wstring       accesspoint;
   std::wstring       ip;
   std::wstring       mac;
+  PowerSaving        powerSaving;
+
   std::list<Network> networks;
 
   Lum::Model::ActionRef statusChangedAction;
@@ -92,6 +103,9 @@ public:
   virtual bool SupportsNetworkRetrieval() const = 0;
 
   virtual bool UpdateNetworks();
+
+  virtual bool CanChangePowerSaving() const;
+  virtual bool SetPowerSaving(bool savePower);
 };
 
 #endif
