@@ -72,6 +72,8 @@ bool StatusHildon::HandleMessage(DBusConnection *connection, DBusMessage *msg)
     return false;
   }
 
+  std::cout << "Handling network scan result..." << std::endl;
+
   Lum::OS::Guard<Lum::OS::Mutex> guard(mutex);
 
   networks.clear();
@@ -131,7 +133,6 @@ bool StatusHildon::HandleMessage(DBusConnection *connection, DBusMessage *msg)
       strValue.erase(strValue.length()-1);
     }
 
-    std::cout << strValue << std::endl;
     network.essid=Lum::Base::StringToWString(strValue);
 
     dbus_message_iter_next(&iter);
@@ -139,14 +140,14 @@ bool StatusHildon::HandleMessage(DBusConnection *connection, DBusMessage *msg)
 
     type=dbus_message_iter_get_arg_type(&iter);
     if (type!=DBUS_TYPE_ARRAY) {
-      std::cerr << "Expected ???" << std::endl;
+      std::cerr << "Expected BSSID" << std::endl;
       return true;
     }
     dbus_message_iter_next(&iter);
 
     type=dbus_message_iter_get_arg_type(&iter);
     if (type!=DBUS_TYPE_INT32) {
-      std::cerr << "Expected ???" << std::endl;
+      std::cerr << "Expected RSSI" << std::endl;
       return true;
     }
     dbus_message_iter_get_basic(&iter,&intValue);
@@ -167,15 +168,18 @@ bool StatusHildon::HandleMessage(DBusConnection *connection, DBusMessage *msg)
 
     type=dbus_message_iter_get_arg_type(&iter);
     if (type!=DBUS_TYPE_UINT32) {
-      std::cerr << "Expected ???" << std::endl;
+      std::cerr << "Expected CHANNEL" << std::endl;
       return true;
     }
     dbus_message_iter_get_basic(&iter,&uintValue);
+
+    network.channel=uintValue;
+
     dbus_message_iter_next(&iter);
 
     type=dbus_message_iter_get_arg_type(&iter);
     if (type!=DBUS_TYPE_UINT32) {
-      std::cerr << "Expected ???" << std::endl;
+      std::cerr << "Expected CAPABILITIES" << std::endl;
       return true;
     }
     dbus_message_iter_get_basic(&iter,&uintValue);
@@ -245,7 +249,7 @@ bool StatusHildon::UpdateNetworks()
   unsigned char   a[] = { 0 };
   unsigned char*  ap=a;
 
-  std::cout << "Sending call..." << std::endl;
+  std::cout << "Requesting network scan..." << std::endl;
 
   msg=dbus_message_new_method_call("com.nokia.wlancond",
                                    "/com/nokia/wlancond/request",
@@ -265,7 +269,43 @@ bool StatusHildon::UpdateNetworks()
 
   dbus_pending_call_set_notify(call,callback,NULL,NULL);
 
-  std::cout << "Sending call done." << std::endl;
+  std::cout << "Requesting network scan done." << std::endl;
 
   return true;
 }
+
+bool StatusHildon::CanChangePowerSaving() const
+{
+  return true;
+}
+
+bool StatusHildon::SetPowerSaving(bool savePower)
+{
+  std::cout << "Requesting power saving switch..." << std::endl;
+
+  DBusMessage *msg;
+  bool        result;
+
+  msg=dbus_message_new_method_call("com.nokia.wlancond",
+                                   "/com/nokia/wlancond/request",
+                                   "com.nokia.wlancond.request",
+                                   "set_powersave");
+
+  dbus_message_append_args(msg,
+                           DBUS_TYPE_BOOLEAN,&savePower,
+                           DBUS_TYPE_INVALID);
+
+  result=dbus_connection_send_with_reply(GetDBusConnection(),msg,NULL,-1);
+
+  dbus_message_unref(msg);
+
+  if (result) {
+    UpdateStatus();
+  }
+  else {
+    std::cout << "Cannot send" << std::endl;
+  }
+
+  return result;
+}
+
