@@ -35,6 +35,9 @@ public:
   bool SupportsNetworkRetrieval() const;
   bool UpdateNetworks();
 
+  bool CanChangePowerSaving() const;
+  bool SetPowerSaving(bool savePower);
+
   bool HandleMessage(DBusConnection *connection, DBusMessage *msg);
 };
 
