@@ -155,6 +155,7 @@ bool StatusLinux::UpdateStatus()
   data.u.essid.length=1024;
 
   if (ioctl(handle,SIOCGIWESSID,&data)>=0) {
+    // TODO: Encode special characters!
     essid=Lum::Base::StringToWString(buffer);
   }
 
@@ -176,6 +177,25 @@ bool StatusLinux::UpdateStatus()
   data.u.data.flags=0;
 
   if (ioctl(handle,SIOCGIWRANGE,&data)>=0) {
+
+    // Frequency
+    memset(&data,0,sizeof(struct iwreq));
+    sprintf(data.ifr_ifrn.ifrn_name,interface.c_str());
+    if (ioctl(handle,SIOCGIWFREQ,&data)>=0) {
+      if (data.u.freq.m<1000 && data.u.freq.e==0) {
+        channel=data.u.freq.m;
+      }
+      else {
+        for (size_t i =0; i<range.num_frequency; i++) {
+          if (data.u.freq.m==range.freq[i].m && data.u.freq.e==range.freq[i].e) {
+            channel=(int)range.freq[i].i;
+            break;
+          }
+        }
+      }
+    }
+
+    // Signal/Noise ratio
     memset(&data,0,sizeof(struct iwreq));
     sprintf(data.ifr_ifrn.ifrn_name,interface.c_str());
     data.u.data.pointer=(caddr_t)&stats;
@@ -217,6 +237,16 @@ bool StatusLinux::UpdateStatus()
     accesspoint=Lum::Base::StringToWString(ether_ntoa(in));
   }
 
+  memset(&data,0,sizeof(struct iwreq));
+  sprintf(data.ifr_ifrn.ifrn_name,interface.c_str());
+  data.u.power.flags=0;
+  if (ioctl(handle,SIOCGIWPOWER,&data)>=0) {
+    powerSaving=data.u.power.disabled ? powerSavingOff : powerSavingOn;
+  }
+  else {
+    powerSaving=powerSavingUnknown;
+  }
+
   close(handle);
 
   Lum::OS::display->QueueActionForEventLoop(statusChangedAction);
